@@ -1,5 +1,5 @@
 from nose.tools import *
-from mongoalchemy.session import Session, FailedOperation
+from mongoalchemy.session import Session
 from mongoalchemy.document import Document, Index, DocumentField
 from mongoalchemy.fields import *
 from test.util import known_failure
@@ -10,18 +10,11 @@ class T(Document):
 def test_session():
     s = Session.connect('unit-testing')
     s.clear_collection(T)
-    s.execute(T(i=1))
+    s.insert(T(i=1))
     s.clear()
     s.end()
 
-@raises(FailedOperation)
-def test_failed_op():
+def test_context_manater():
     with Session.connect('unit-testing') as s:
         s.clear_collection(T)
         t = T(i=5)
-        try:
-            raise Exception()
-        except Exception, e:
-            fo = FailedOperation(t, e)
-            str(fo) # for coverage
-            raise fo
\ No newline at end of file
